#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .n_theta_divisions import n_theta_divisions
from .n_phi_divisions import n_phi_divisions
from .n_theta_pixels import n_theta_pixels
from .n_phi_pixels import n_phi_pixels
class discrete_ordinates(Group):
    """
    Enable/disable the discrete ordinates radiation model.
    """

    fluent_name = "discrete-ordinates"

    child_names = \
        ['n_theta_divisions', 'n_phi_divisions', 'n_theta_pixels',
         'n_phi_pixels']

    n_theta_divisions: n_theta_divisions = n_theta_divisions
    """
    n_theta_divisions child of discrete_ordinates.
    """
    n_phi_divisions: n_phi_divisions = n_phi_divisions
    """
    n_phi_divisions child of discrete_ordinates.
    """
    n_theta_pixels: n_theta_pixels = n_theta_pixels
    """
    n_theta_pixels child of discrete_ordinates.
    """
    n_phi_pixels: n_phi_pixels = n_phi_pixels
    """
    n_phi_pixels child of discrete_ordinates.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .model import model
from .options_2 import options
from .reactions import reactions
from .wall_surface_options import wall_surface_options
from .turb_chem_interaction_model import turb_chem_interaction_model
from .turb_chem_interaction_model_options import turb_chem_interaction_model_options
from .species_transport_expert_options import species_transport_expert_options
from .edc_model_options import edc_model_options
from .tfm_model_options import tfm_model_options
from .chemistry_solver import chemistry_solver
from .integration_parameters import integration_parameters
class species(Group):
    """
    'species' child.
    """

    fluent_name = "species"

    child_names = \
        ['model', 'options', 'reactions', 'wall_surface_options',
         'turb_chem_interaction_model', 'turb_chem_interaction_model_options',
         'species_transport_expert_options', 'edc_model_options',
         'tfm_model_options', 'chemistry_solver', 'integration_parameters']

    model: model = model
    """
    model child of species.
    """
    options: options = options
    """
    options child of species.
    """
    reactions: reactions = reactions
    """
    reactions child of species.
    """
    wall_surface_options: wall_surface_options = wall_surface_options
    """
    wall_surface_options child of species.
    """
    turb_chem_interaction_model: turb_chem_interaction_model = turb_chem_interaction_model
    """
    turb_chem_interaction_model child of species.
    """
    turb_chem_interaction_model_options: turb_chem_interaction_model_options = turb_chem_interaction_model_options
    """
    turb_chem_interaction_model_options child of species.
    """
    species_transport_expert_options: species_transport_expert_options = species_transport_expert_options
    """
    species_transport_expert_options child of species.
    """
    edc_model_options: edc_model_options = edc_model_options
    """
    edc_model_options child of species.
    """
    tfm_model_options: tfm_model_options = tfm_model_options
    """
    tfm_model_options child of species.
    """
    chemistry_solver: chemistry_solver = chemistry_solver
    """
    chemistry_solver child of species.
    """
    integration_parameters: integration_parameters = integration_parameters
    """
    integration_parameters child of species.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class open_channel_wave_bc(Boolean):
    """
    'open_channel_wave_bc' child.
    """

    fluent_name = "open-channel-wave-bc?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class position_on_y_axis(Boolean):
    """
    'position_on_y_axis' child.
    """

    fluent_name = "position-on-y-axis?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

"""A package providing Fluent's Settings Objects in Python."""
from ansys.fluent.core.solver.flobject import *

SHASH = "98e946a856990f4633cf6a2a69a629e3f70977ec7400f7b8268bcd525ab3c3fa"
from .root import root


#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .real_gas_nist import real_gas_nist
from .value import value
from .compressible_liquid import compressible_liquid
from .piecewise_linear import piecewise_linear
from .piecewise_polynomial import piecewise_polynomial
from .polynomial import polynomial
from .expression import expression
from .user_defined_function import user_defined_function
from .rgp_table import rgp_table
class density(Group):
    """
    'density' child.
    """

    fluent_name = "density"

    child_names = \
        ['option', 'real_gas_nist', 'value', 'compressible_liquid',
         'piecewise_linear', 'piecewise_polynomial', 'polynomial',
         'expression', 'user_defined_function', 'rgp_table']

    option: option = option
    """
    option child of density.
    """
    real_gas_nist: real_gas_nist = real_gas_nist
    """
    real_gas_nist child of density.
    """
    value: value = value
    """
    value child of density.
    """
    compressible_liquid: compressible_liquid = compressible_liquid
    """
    compressible_liquid child of density.
    """
    piecewise_linear: piecewise_linear = piecewise_linear
    """
    piecewise_linear child of density.
    """
    piecewise_polynomial: piecewise_polynomial = piecewise_polynomial
    """
    piecewise_polynomial child of density.
    """
    polynomial: polynomial = polynomial
    """
    polynomial child of density.
    """
    expression: expression = expression
    """
    expression child of density.
    """
    user_defined_function: user_defined_function = user_defined_function
    """
    user_defined_function child of density.
    """
    rgp_table: rgp_table = rgp_table
    """
    rgp_table child of density.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .multiband_child import multiband_child

class multiband(NamedObject[multiband_child], _CreatableNamedObjectMixin[multiband_child]):
    """
    Enter multi-band information.
    """

    fluent_name = "multiband"

    child_object_type: multiband_child = multiband_child
    """
    child_object_type of multiband.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class ray_points_count(Integer):
    """
    Set the number of grid point in each ray of the optical beam.
    """

    fluent_name = "ray-points-count"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class porous_jump_turb_wall_treatment(Boolean):
    """
    'porous_jump_turb_wall_treatment' child.
    """

    fluent_name = "porous-jump-turb-wall-treatment?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .p0 import p0
from .p1 import p1
from .number_of_points import number_of_points
class rake_surface_child(Group):
    """
    'child_object_type' of rake_surface.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['p0', 'p1', 'number_of_points']

    p0: p0 = p0
    """
    p0 child of rake_surface_child.
    """
    p1: p1 = p1
    """
    p1 child of rake_surface_child.
    """
    number_of_points: number_of_points = number_of_points
    """
    number_of_points child of rake_surface_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class helper_session(Boolean):
    """
    Setup session mode (single/multiple) for multidomain conjugate heat transfer.
    """

    fluent_name = "helper-session?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .value import value
from .delta_eddington import delta_eddington
from .user_defined_function import user_defined_function
class scattering_phase_function(Group):
    """
    'scattering_phase_function' child.
    """

    fluent_name = "scattering-phase-function"

    child_names = \
        ['option', 'value', 'delta_eddington', 'user_defined_function']

    option: option = option
    """
    option child of scattering_phase_function.
    """
    value: value = value
    """
    value child of scattering_phase_function.
    """
    delta_eddington: delta_eddington = delta_eddington
    """
    delta_eddington child of scattering_phase_function.
    """
    user_defined_function: user_defined_function = user_defined_function
    """
    user_defined_function child of scattering_phase_function.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .dynamic_mechanism_reduction_tolerance import dynamic_mechanism_reduction_tolerance
from .dynamic_mechanism_reduction_expert import dynamic_mechanism_reduction_expert
from .dynamic_mechanism_reduction_min_target import dynamic_mechanism_reduction_min_target
from .dynamic_mechanism_reduction_targets import dynamic_mechanism_reduction_targets
class dynamic_mechanism_reduction_options(Group):
    """
    'dynamic_mechanism_reduction_options' child.
    """

    fluent_name = "dynamic-mechanism-reduction-options"

    child_names = \
        ['dynamic_mechanism_reduction_tolerance',
         'dynamic_mechanism_reduction_expert',
         'dynamic_mechanism_reduction_min_target',
         'dynamic_mechanism_reduction_targets']

    dynamic_mechanism_reduction_tolerance: dynamic_mechanism_reduction_tolerance = dynamic_mechanism_reduction_tolerance
    """
    dynamic_mechanism_reduction_tolerance child of dynamic_mechanism_reduction_options.
    """
    dynamic_mechanism_reduction_expert: dynamic_mechanism_reduction_expert = dynamic_mechanism_reduction_expert
    """
    dynamic_mechanism_reduction_expert child of dynamic_mechanism_reduction_options.
    """
    dynamic_mechanism_reduction_min_target: dynamic_mechanism_reduction_min_target = dynamic_mechanism_reduction_min_target
    """
    dynamic_mechanism_reduction_min_target child of dynamic_mechanism_reduction_options.
    """
    dynamic_mechanism_reduction_targets: dynamic_mechanism_reduction_targets = dynamic_mechanism_reduction_targets
    """
    dynamic_mechanism_reduction_targets child of dynamic_mechanism_reduction_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class y_beam_vector(Real):
    """
    Set the y-component of the beam propagation vector.
    """

    fluent_name = "y-beam-vector"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .line_surface_child import line_surface_child

class line_surface(NamedObject[line_surface_child], _CreatableNamedObjectMixin[line_surface_child]):
    """
    'line_surface' child.
    """

    fluent_name = "line-surface"

    child_object_type: line_surface_child = line_surface_child
    """
    child_object_type of line_surface.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class confirm_overwrite(Boolean):
    """
    Indicate whether or not to confirm attempts to overwrite existing files.
    """

    fluent_name = "confirm-overwrite?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class swirl_dominated_flow(Boolean):
    """
    Enable/disable swirl corrections for rng-model.
    """

    fluent_name = "swirl-dominated-flow"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_volumetric_reactions import enable_volumetric_reactions
from .enable_wall_surface import enable_wall_surface
from .enable_particle_surface import enable_particle_surface
from .enable_electrochemical_surface import enable_electrochemical_surface
class reactions(Group):
    """
    'reactions' child.
    """

    fluent_name = "reactions"

    child_names = \
        ['enable_volumetric_reactions', 'enable_wall_surface',
         'enable_particle_surface', 'enable_electrochemical_surface']

    enable_volumetric_reactions: enable_volumetric_reactions = enable_volumetric_reactions
    """
    enable_volumetric_reactions child of reactions.
    """
    enable_wall_surface: enable_wall_surface = enable_wall_surface
    """
    enable_wall_surface child of reactions.
    """
    enable_particle_surface: enable_particle_surface = enable_particle_surface
    """
    enable_particle_surface child of reactions.
    """
    enable_electrochemical_surface: enable_electrochemical_surface = enable_electrochemical_surface
    """
    enable_electrochemical_surface child of reactions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class dynamic_mechanism_reduction_expert(Boolean):
    """
    Enable expert options for dynamic mechanism reduction.
    """

    fluent_name = "dynamic-mechanism-reduction-expert"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class rough_shin_et_al(Boolean):
    """
    'rough_shin_et_al' child.
    """

    fluent_name = "rough-shin-et-al?"

